---
title: Introducing Nomic on breadpunk.club
date: 2020-04-15
---

This was initially posted on the `bread.nomic` newsgroup on breadpunk's
[private nntp server](/docs/news) on April 13<sup>th</sup> 2020 and has
been ported here due to how big of an essay it turned out to be.

------

So… since this newsgroup is pretty obviously dedicated to Nomic games,
we might as well do some of them.  But since this will be a first game,
I will start by summarizing what is Nomic, then suggest how we could in
practice play this game, in a way that is adapted to Breadpunk.

I hope you are prepared to read a giant wall of text.

## About Nomic

Nomic is a self-modifying game;  the whole point of it is to change its
rules. The game was created by Peter Suber, as part of a book about one
of the strange implications of the law:  laws are defined by laws,  and
since laws can change laws, laws might change the concept of the law in
some strange recursion, in a process called "self-amendment". The point
of Nomic is to extract this concept of recursive definition and make it
the only point of laws to be changing themselves.

Suber provides an initial ruleset on his [Nomic web page][1], describing
two types of rules: immutable and mutable rules.  This split is similar
to the difference between a constitution and a bill: both are laws, but
a constitution is defined as overriding the laws.  The rules make it so
that on each turn, each player has to make a proposal to change a rule,
and the proposal has to be voted on by all other players.  Changing the
type of a rule from immutable to mutable and vice-versa is possible and
is considered an atomic rule-change,  making the process of changing an
immutable rule not impossible but slightly harder,  as it would require
two different rule changes in two different moves.

The ruleset takes into consideration the situations where one plays via
mail or via a computer, for example in Rule 210 mentioning that players
should not discuss future rule changes with each other,  unless playing
via mail or computer,  or Rule 202 mentioning throwing one die,  except
when playing via mail or computer, as one could easily cheat and always
throw a 6 by some case of extreme luck;  remote players have to do some
calculations based on the rule number and amount of positive votes.

There are online games of Nomic that have lasted for over 20 years, and
that are so complex that they now require a wiki or other specific apps
and websites for players to be able to play them properly.  One example
of such terrific games is [Agora Nomic][2], a game started on June 30th,
1993, and that is still running today.  There also are some interesting
variants of Nomic,  such as starting a new game with an existing game's
ruleset (like a self-modifying Monopoly),  or to create some paradoxes,
Mornington Crescent, a game whose rules never are made perfectly clear.

A friend of mine has created the [Mornington Nomic][3] variant: the goal
no longer is to explore the concept of a rule but more to build a board
game, initially centered around the map of the London Underground.
Imperial Nomic, a well-known variant initially named Fascist Nomic, has
a single player who is unable to win, but gets to vote on all proposals
made by all the other players.

## Playing on Breadpunk

This is definitely not a factual guide nor an exact updated ruleset for
playing Nomic on this server,  but a suggestion and a discussion of how
this could be implemented. Feedback is very welcome.

An important note about Nomic is that while two-player Nomic is neither
forbidden nor impossible, it is quite boring:  each player has complete
control over the other player's proposals.  Therefore, we will probably
need at least three players to play a proper game on here.

I suggest using the following process to play a game of Nomic and allow
everyone easy access to the current rules and its history:

- A Git repository on Tildegit contains the active ruleset as well as a
  directory holding the summaries of possible Judgements (see Rule 212)
- On each turn,  a player makes a rule change via a post to this group,
  along with a link to a pull request to this repository.  The post can
  include detailed information about the "why" of a rule change or just
  whatever the player wants to say,  but the pull request is considered
  the "ground truth" and clearly shows what change to the ruleset would
  be made.
- Players may vote using the thumbs up and down buttons on a PR.  There
  can only be one open pull request at a time,  as there should only be
  one on-going vote at a time according to the initial rules.
- An accepted proposal gets its pull request merged, a rejected one has
  its pull request closed.

This would allow anyone to browse the ruleset using a browser,  which I
think many of us would find more comfortable, would perfectly well deal
with potentially huge games, and would cleanly display the game's state
and history.

This "Nomgit" however has the potential of  1) making playing a game of
Nomic a chore, as it requires to go through the whole Git workflow, and
2) increasing confusion as of where some piece of information is, as we
would have both a Git repo and a newsgroup for the game.

Another possibility is just to have the Git repos be companions of each
game, just as a tool to help us browse the rules. This could cause some
issues about whether or not the Git repository is trustable as a source
of truth, causing some possible legal issues and subsequent invocations
of Rule 212,  aka playing around with the possible loopholes in a rule.
This can be considered a problem with this method of play, or something
that would be part of the game, if some players turn into "lawyers" and
really orient the game towards fucking up the rules.  That is something
I am definitely looking forward to in a game of Nomic.

I consider it important to have another place to keep an history, since
newsgroups originally were not intended to keep messages forever — the
current configuration of our NNTP server makes it so that sent messages
never expire,  simply because the CRON job to expire posts has not been
configured, which means expiration could happen in the future and older
posts can disappear suddenly.

The concept of Nomgit could also turn into an interesting Nomic variant
where a Git repository becomes the one single place where the game gets
played,  and multiple rule changes can be proposed by any player at any
time just by opening a pull request, removing the turn-based portion of
Nomic.  I will probably expand further on this on my breadsite later.

Finally, another option I imagine is just to not care about history and
to instead rely on the players: just as suggested for paper-based play,
each players keeps a copy of the rules,  organized in whatever way they
might prefer, and they are each in charge of taking care of their notes
and keeping them up to date.  This can definitely lead to more cases of
confusion and disagreement, which can again be seen either as a problem
or as a desirable side effect.

Feel free to send me any feedback you have, questions, remarks, or even
suggestions of new variants.  Please do advertise the fact that we will
play some games of Nomic on here, to help more bakers get interested in
it; while I mention my readers in plural, I only expect ~breadw to read
this as he is the only one who expressed interest in Nomic.

[1]: http://legacy.earlham.edu/~peters/writing/nomic.htm
[2]: //agoranomic.org/
[3]: //averylychee.neocities.org/mornington-nomic/
